@@ -20,7 +20,9 @@ class USwapper:
         returns:
             price in eth
         """
-        call = f'{{tokens(where: {{symbol: "{symbol}"}})' \
+        a = str(self.gettokenaddress(symbol))
+
+        call = f'{{tokens(where: {{id: "{a}"}})' \
                f'{{derivedETH}}}}'
         price = float(self.client.execute(call)['data']['tokens'][0]['derivedETH'])
         return price
@@ -33,9 +35,8 @@ class USwapper:
         returns:
             token address
         """
-        addv = self.ass[self.ass['symbol'] == str.upper(symbol)]['id']
-        addv.reset_index(inplace=True, drop=True)
-        return addv[0]
+        i = self.ass[self.ass['symbol'] == str.upper(symbol)]['id'].first_valid_index()
+        return self.ass.id[i]
 
     def gettokensymbol(self, address):
         addv = self.ass[self.ass['id'] == address]['symbol']
@@ -55,7 +56,7 @@ class USwapper:
             n += 1
 
             call = f'' \
-                   f'{{tokens(first:1000, orderDirection: desc, orderBy: tradeVolumeUSD, skip: {n * 1000}) ' \
+                   f'{{tokens(first:1000, orderDirection: desc, orderBy: txCount, skip: {n * 1000}) ' \
                    f'{{' \
                    f'id ' \
                    f'symbol ' \
